@@ -1,6 +1,6 @@
 /*
  * sauce.h
- * Ansilove 4.1.0
+ * Ansilove 4.1.1
  * https://www.ansilove.org
  *
  * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
@@ -13,7 +13,7 @@
 #ifndef SAUCE_H
 #define SAUCE_H
 
-#include <sys/types.h>
+#include <stdint.h>
 #include <stdio.h>
 
 /* sauce records */
