@@ -1,6 +1,6 @@
 /*
  * types.h
- * Ansilove 4.1.0
+ * Ansilove 4.1.1
  * https://www.ansilove.org
  *
  * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
@@ -21,6 +21,9 @@
 #define ANSILOVE_FILETYPE_TND	6
 #define ANSILOVE_FILETYPE_XB	7
 
+struct ansilove_ctx;
+struct ansilove_options;
+
 extern char *types[];
 extern int filetypes[];
 extern int (*loaders[])(struct ansilove_ctx *, struct ansilove_options *);
